# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_match_metadata.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.base_gcmessages_pb2 as base__gcmessages__pb2
import dota2.protobufs.dota_gcmessages_common_match_management_pb2 as dota__gcmessages__common__match__management__pb2
import dota2.protobufs.dota_gcmessages_common_pb2 as dota__gcmessages__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_match_metadata.proto',
  package='dota',
  syntax='proto2',
  serialized_options=_b('\220\001\000'),
  serialized_pb=_b('\n\x19\x64ota_match_metadata.proto\x12\x04\x64ota\x1a\x15\x62\x61se_gcmessages.proto\x1a-dota_gcmessages_common_match_management.proto\x1a\x1c\x64ota_gcmessages_common.proto\"\x81\x01\n\x16\x43\x44OTAMatchMetadataFile\x12\x0f\n\x07version\x18\x01 \x02(\x05\x12\x10\n\x08match_id\x18\x02 \x02(\x04\x12*\n\x08metadata\x18\x03 \x01(\x0b\x32\x18.dota.CDOTAMatchMetadata\x12\x18\n\x10private_metadata\x18\x05 \x01(\x0c\"\x99\x1b\n\x12\x43\x44OTAMatchMetadata\x12,\n\x05teams\x18\x01 \x03(\x0b\x32\x1d.dota.CDOTAMatchMetadata.Team\x12\x34\n\x0citem_rewards\x18\x02 \x03(\x0b\x32\x1e.dota.CLobbyTimedRewardDetails\x12\x10\n\x08lobby_id\x18\x03 \x01(\x06\x12\x19\n\x11report_until_time\x18\x04 \x01(\x06\x12\x1f\n\x17\x65vent_game_custom_table\x18\x05 \x01(\x0c\x12\x18\n\x10primary_event_id\x18\x06 \x01(\r\x12\'\n\nmatch_tips\x18\x07 \x03(\x0b\x32\x13.dota.CMsgMatchTips\x1a\x8d\x19\n\x04Team\x12\x11\n\tdota_team\x18\x01 \x01(\r\x12\x35\n\x07players\x18\x02 \x03(\x0b\x32$.dota.CDOTAMatchMetadata.Team.Player\x12\x18\n\x10graph_experience\x18\x03 \x03(\x02\x12\x19\n\x11graph_gold_earned\x18\x04 \x03(\x02\x12\x17\n\x0fgraph_net_worth\x18\x05 \x03(\x02\x12\x15\n\rcm_first_pick\x18\x06 \x01(\x08\x12\x1c\n\x14\x63m_captain_player_id\x18\x07 \x01(\r\x12\x0f\n\x07\x63m_bans\x18\x08 \x03(\r\x12\x10\n\x08\x63m_picks\x18\t \x03(\r\x12\x12\n\ncm_penalty\x18\n \x01(\r\x1a\x30\n\nPlayerKill\x12\x13\n\x0bvictim_slot\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x1a\x36\n\x0cItemPurchase\x12\x0f\n\x07item_id\x18\x01 \x01(\r\x12\x15\n\rpurchase_time\x18\x02 \x01(\x05\x1av\n\x11InventorySnapshot\x12\x0f\n\x07item_id\x18\x01 \x03(\r\x12\x11\n\tgame_time\x18\x02 \x01(\x05\x12\r\n\x05kills\x18\x03 \x01(\r\x12\x0e\n\x06\x64\x65\x61ths\x18\x04 \x01(\r\x12\x0f\n\x07\x61ssists\x18\x05 \x01(\r\x12\r\n\x05level\x18\x06 \x01(\r\x1a\x36\n\x11\x41utoStyleCriteria\x12\x12\n\nname_token\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x02\x1a\xc6\x01\n\x12StrangeGemProgress\x12\x17\n\x0fkill_eater_type\x18\x01 \x01(\r\x12\x1a\n\x12gem_item_def_index\x18\x02 \x01(\r\x12\x18\n\x10required_hero_id\x18\x03 \x01(\r\x12\x16\n\x0estarting_value\x18\x04 \x01(\r\x12\x14\n\x0c\x65nding_value\x18\x05 \x01(\r\x12\x1c\n\x14owner_item_def_index\x18\x06 \x01(\r\x12\x15\n\rowner_item_id\x18\x07 \x01(\x04\x1ah\n\x11VictoryPrediction\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x16\n\x0eitem_def_index\x18\x02 \x01(\r\x12\x16\n\x0estarting_value\x18\x03 \x01(\r\x12\x12\n\nis_victory\x18\x04 \x01(\x08\x1aZ\n\x0cSubChallenge\x12\x0f\n\x07slot_id\x18\x01 \x01(\r\x12\x13\n\x0bstart_value\x18\x02 \x01(\r\x12\x11\n\tend_value\x18\x03 \x01(\r\x12\x11\n\tcompleted\x18\x04 \x01(\x08\x1aK\n\x15\x43\x61vernChallengeResult\x12\x19\n\x11\x63ompleted_path_id\x18\x01 \x01(\r\x12\x17\n\x0f\x63laimed_room_id\x18\x02 \x01(\r\x1a\x41\n\x0b\x41\x63tionGrant\x12\x11\n\taction_id\x18\x01 \x01(\r\x12\x10\n\x08quantity\x18\x02 \x01(\r\x12\r\n\x05\x61udit\x18\x03 \x01(\r\x1a\xe7\x05\n\tEventData\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\r\x12\x14\n\x0c\x65vent_points\x18\x02 \x01(\r\x12\x1d\n\x15\x63hallenge_instance_id\x18\x03 \x01(\r\x12\x1a\n\x12\x63hallenge_quest_id\x18\x04 \x01(\r\x12$\n\x1c\x63hallenge_quest_challenge_id\x18\x05 \x01(\r\x12\x1b\n\x13\x63hallenge_completed\x18\x06 \x01(\x08\x12 \n\x18\x63hallenge_rank_completed\x18\x07 \x01(\r\x12+\n#challenge_rank_previously_completed\x18\x08 \x01(\r\x12\x13\n\x0b\x65vent_owned\x18\t \x01(\x08\x12P\n\x1csub_challenges_with_progress\x18\n \x03(\x0b\x32*.dota.CDOTAMatchMetadata.Team.SubChallenge\x12\x16\n\x0ewager_winnings\x18\x0b \x01(\r\x12\x1f\n\x17\x63\x61vern_challenge_active\x18\x0c \x01(\x08\x12!\n\x19\x63\x61vern_challenge_winnings\x18\r \x01(\r\x12\x16\n\x0e\x61mount_wagered\x18\x0e \x01(\r\x12\x19\n\x11team_wager_amount\x18\x0f \x01(\r\x12\"\n\x1aperiodic_point_adjustments\x18\x10 \x01(\r\x12Y\n\x1c\x63\x61vern_challenge_map_results\x18\x11 \x03(\x0b\x32\x33.dota.CDOTAMatchMetadata.Team.CavernChallengeResult\x12,\n$cavern_challenge_plus_shard_winnings\x18\x12 \x01(\r\x12\x42\n\x0f\x61\x63tions_granted\x18\x13 \x03(\x0b\x32).dota.CDOTAMatchMetadata.Team.ActionGrant\x1a\xdd\n\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x18\n\x10\x61\x62ility_upgrades\x18\x02 \x03(\r\x12\x13\n\x0bplayer_slot\x18\x03 \x01(\r\x12.\n\x13\x65quipped_econ_items\x18\x04 \x03(\x0b\x32\x11.dota.CSOEconItem\x12\x37\n\x05kills\x18\x05 \x03(\x0b\x32(.dota.CDOTAMatchMetadata.Team.PlayerKill\x12\x39\n\x05items\x18\x06 \x03(\x0b\x32*.dota.CDOTAMatchMetadata.Team.ItemPurchase\x12\x15\n\ravg_kills_x16\x18\x07 \x01(\r\x12\x16\n\x0e\x61vg_deaths_x16\x18\x08 \x01(\r\x12\x17\n\x0f\x61vg_assists_x16\x18\t \x01(\r\x12\x13\n\x0b\x61vg_gpm_x16\x18\n \x01(\r\x12\x13\n\x0b\x61vg_xpm_x16\x18\x0b \x01(\r\x12\x16\n\x0e\x62\x65st_kills_x16\x18\x0c \x01(\r\x12\x18\n\x10\x62\x65st_assists_x16\x18\r \x01(\r\x12\x14\n\x0c\x62\x65st_gpm_x16\x18\x0e \x01(\r\x12\x14\n\x0c\x62\x65st_xpm_x16\x18\x0f \x01(\r\x12\x12\n\nwin_streak\x18\x10 \x01(\r\x12\x17\n\x0f\x62\x65st_win_streak\x18\x11 \x01(\r\x12\x13\n\x0b\x66ight_score\x18\x12 \x01(\x02\x12\x12\n\nfarm_score\x18\x13 \x01(\x02\x12\x15\n\rsupport_score\x18\x14 \x01(\x02\x12\x12\n\npush_score\x18\x15 \x01(\x02\x12\x16\n\x0elevel_up_times\x18\x16 \x03(\r\x12\x17\n\x0fgraph_net_worth\x18\x17 \x03(\x02\x12K\n\x12inventory_snapshot\x18\x18 \x03(\x0b\x32/.dota.CDOTAMatchMetadata.Team.InventorySnapshot\x12\x1c\n\x14\x61vg_stats_calibrated\x18\x19 \x01(\x08\x12L\n\x13\x61uto_style_criteria\x18\x1a \x03(\x0b\x32/.dota.CDOTAMatchMetadata.Team.AutoStyleCriteria\x12;\n\nevent_data\x18\x1d \x03(\x0b\x32\'.dota.CDOTAMatchMetadata.Team.EventData\x12N\n\x14strange_gem_progress\x18\x1e \x03(\x0b\x32\x30.dota.CDOTAMatchMetadata.Team.StrangeGemProgress\x12\x0f\n\x07hero_xp\x18\x1f \x01(\r\x12\x15\n\rcamps_stacked\x18  \x01(\r\x12K\n\x12victory_prediction\x18! \x03(\x0b\x32/.dota.CDOTAMatchMetadata.Team.VictoryPrediction\x12\x1c\n\x14lane_selection_flags\x18\" \x01(\r\x12\x10\n\x08rampages\x18# \x01(\r\x12\x14\n\x0ctriple_kills\x18$ \x01(\r\x12\x16\n\x0e\x61\x65gis_snatched\x18% \x01(\r\x12\x19\n\x11rapiers_purchased\x18& \x01(\r\x12\x17\n\x0f\x63ouriers_killed\x18\' \x01(\r\x12\x16\n\x0enet_worth_rank\x18( \x01(\r\x12\x1a\n\x12support_gold_spent\x18) \x01(\r\x12\x1d\n\x15observer_wards_placed\x18* \x01(\r\x12\x1b\n\x13sentry_wards_placed\x18+ \x01(\r\x12\x16\n\x0ewards_dewarded\x18, \x01(\r\x12\x15\n\rstun_duration\x18- \x01(\x02\"\xcc\n\n\x19\x43\x44OTAMatchPrivateMetadata\x12\x33\n\x05teams\x18\x01 \x03(\x0b\x32$.dota.CDOTAMatchPrivateMetadata.Team\x12\x1d\n\x15graph_win_probability\x18\x02 \x03(\x02\x1a\xda\t\n\x04Team\x12\x11\n\tdota_team\x18\x01 \x01(\r\x12<\n\x07players\x18\x02 \x03(\x0b\x32+.dota.CDOTAMatchPrivateMetadata.Team.Player\x12@\n\tbuildings\x18\x03 \x03(\x0b\x32-.dota.CDOTAMatchPrivateMetadata.Team.Building\x1a\xd7\x07\n\x06Player\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0bplayer_slot\x18\x02 \x01(\r\x12\x17\n\x0fposition_stream\x18\x03 \x01(\x0c\x12R\n\x0f\x63ombat_segments\x18\x04 \x03(\x0b\x32\x39.dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment\x12\x19\n\x11\x64\x61mage_unit_names\x18\x05 \x03(\t\x12L\n\x0c\x62uff_records\x18\x06 \x03(\x0b\x32\x36.dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord\x12\x13\n\x0bgraph_kills\x18\x07 \x03(\x02\x12\x14\n\x0cgraph_deaths\x18\x08 \x03(\x02\x12\x15\n\rgraph_assists\x18\t \x03(\x02\x12\x16\n\x0egraph_lasthits\x18\n \x03(\x02\x12\x14\n\x0cgraph_denies\x18\x0b \x03(\x02\x1a\xed\x02\n\rCombatSegment\x12\x11\n\tgame_time\x18\x01 \x01(\x05\x12\x64\n\x11\x64\x61mage_by_ability\x18\x02 \x03(\x0b\x32I.dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility\x1a\xe2\x01\n\x0f\x44\x61mageByAbility\x12\x19\n\x11source_unit_index\x18\x03 \x01(\r\x12\x12\n\nability_id\x18\x01 \x01(\r\x12o\n\x0f\x62y_hero_targets\x18\x02 \x03(\x0b\x32V.dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.ByHeroTarget\x1a/\n\x0c\x42yHeroTarget\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x0e\n\x06\x64\x61mage\x18\x02 \x01(\r\x1a\xed\x01\n\nBuffRecord\x12\x17\n\x0f\x62uff_ability_id\x18\x01 \x01(\r\x12\x1a\n\x12\x62uff_modifier_name\x18\x03 \x01(\t\x12\\\n\x0f\x62y_hero_targets\x18\x02 \x03(\x0b\x32\x43.dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.ByHeroTarget\x1aL\n\x0c\x42yHeroTarget\x12\x0f\n\x07hero_id\x18\x01 \x01(\r\x12\x18\n\x10\x65lapsed_duration\x18\x02 \x01(\x02\x12\x11\n\tis_hidden\x18\x03 \x01(\x08\x1a\x65\n\x08\x42uilding\x12\x11\n\tunit_name\x18\x01 \x01(\t\x12\x18\n\x10position_quant_x\x18\x02 \x01(\r\x12\x18\n\x10position_quant_y\x18\x03 \x01(\r\x12\x12\n\ndeath_time\x18\x04 \x01(\x02\"b\n\x10\x43MsgDOTADPCMatch\x12\"\n\x05match\x18\x01 \x01(\x0b\x32\x13.dota.CMsgDOTAMatch\x12*\n\x08metadata\x18\x02 \x01(\x0b\x32\x18.dota.CDOTAMatchMetadataB\x03\x90\x01\x00')
  ,
  dependencies=[base__gcmessages__pb2.DESCRIPTOR,dota__gcmessages__common__match__management__pb2.DESCRIPTOR,dota__gcmessages__common__pb2.DESCRIPTOR,])




_CDOTAMATCHMETADATAFILE = _descriptor.Descriptor(
  name='CDOTAMatchMetadataFile',
  full_name='dota.CDOTAMatchMetadataFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CDOTAMatchMetadataFile.version', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_id', full_name='dota.CDOTAMatchMetadataFile.match_id', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dota.CDOTAMatchMetadataFile.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_metadata', full_name='dota.CDOTAMatchMetadataFile.private_metadata', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=265,
)


_CDOTAMATCHMETADATA_TEAM_PLAYERKILL = _descriptor.Descriptor(
  name='PlayerKill',
  full_name='dota.CDOTAMatchMetadata.Team.PlayerKill',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='victim_slot', full_name='dota.CDOTAMatchMetadata.Team.PlayerKill.victim_slot', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='dota.CDOTAMatchMetadata.Team.PlayerKill.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=804,
  serialized_end=852,
)

_CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE = _descriptor.Descriptor(
  name='ItemPurchase',
  full_name='dota.CDOTAMatchMetadata.Team.ItemPurchase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CDOTAMatchMetadata.Team.ItemPurchase.item_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_time', full_name='dota.CDOTAMatchMetadata.Team.ItemPurchase.purchase_time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=908,
)

_CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT = _descriptor.Descriptor(
  name='InventorySnapshot',
  full_name='dota.CDOTAMatchMetadata.Team.InventorySnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CDOTAMatchMetadata.Team.InventorySnapshot.item_id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_time', full_name='dota.CDOTAMatchMetadata.Team.InventorySnapshot.game_time', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kills', full_name='dota.CDOTAMatchMetadata.Team.InventorySnapshot.kills', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deaths', full_name='dota.CDOTAMatchMetadata.Team.InventorySnapshot.deaths', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assists', full_name='dota.CDOTAMatchMetadata.Team.InventorySnapshot.assists', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='dota.CDOTAMatchMetadata.Team.InventorySnapshot.level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=1028,
)

_CDOTAMATCHMETADATA_TEAM_AUTOSTYLECRITERIA = _descriptor.Descriptor(
  name='AutoStyleCriteria',
  full_name='dota.CDOTAMatchMetadata.Team.AutoStyleCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name_token', full_name='dota.CDOTAMatchMetadata.Team.AutoStyleCriteria.name_token', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dota.CDOTAMatchMetadata.Team.AutoStyleCriteria.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1084,
)

_CDOTAMATCHMETADATA_TEAM_STRANGEGEMPROGRESS = _descriptor.Descriptor(
  name='StrangeGemProgress',
  full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kill_eater_type', full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress.kill_eater_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gem_item_def_index', full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress.gem_item_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required_hero_id', full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress.required_hero_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='starting_value', full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress.starting_value', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ending_value', full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress.ending_value', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_item_def_index', full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress.owner_item_def_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_item_id', full_name='dota.CDOTAMatchMetadata.Team.StrangeGemProgress.owner_item_id', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1285,
)

_CDOTAMATCHMETADATA_TEAM_VICTORYPREDICTION = _descriptor.Descriptor(
  name='VictoryPrediction',
  full_name='dota.CDOTAMatchMetadata.Team.VictoryPrediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CDOTAMatchMetadata.Team.VictoryPrediction.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='dota.CDOTAMatchMetadata.Team.VictoryPrediction.item_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='starting_value', full_name='dota.CDOTAMatchMetadata.Team.VictoryPrediction.starting_value', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_victory', full_name='dota.CDOTAMatchMetadata.Team.VictoryPrediction.is_victory', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1287,
  serialized_end=1391,
)

_CDOTAMATCHMETADATA_TEAM_SUBCHALLENGE = _descriptor.Descriptor(
  name='SubChallenge',
  full_name='dota.CDOTAMatchMetadata.Team.SubChallenge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot_id', full_name='dota.CDOTAMatchMetadata.Team.SubChallenge.slot_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_value', full_name='dota.CDOTAMatchMetadata.Team.SubChallenge.start_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_value', full_name='dota.CDOTAMatchMetadata.Team.SubChallenge.end_value', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed', full_name='dota.CDOTAMatchMetadata.Team.SubChallenge.completed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1483,
)

_CDOTAMATCHMETADATA_TEAM_CAVERNCHALLENGERESULT = _descriptor.Descriptor(
  name='CavernChallengeResult',
  full_name='dota.CDOTAMatchMetadata.Team.CavernChallengeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='completed_path_id', full_name='dota.CDOTAMatchMetadata.Team.CavernChallengeResult.completed_path_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='claimed_room_id', full_name='dota.CDOTAMatchMetadata.Team.CavernChallengeResult.claimed_room_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1485,
  serialized_end=1560,
)

_CDOTAMATCHMETADATA_TEAM_ACTIONGRANT = _descriptor.Descriptor(
  name='ActionGrant',
  full_name='dota.CDOTAMatchMetadata.Team.ActionGrant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_id', full_name='dota.CDOTAMatchMetadata.Team.ActionGrant.action_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='dota.CDOTAMatchMetadata.Team.ActionGrant.quantity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audit', full_name='dota.CDOTAMatchMetadata.Team.ActionGrant.audit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1627,
)

_CDOTAMATCHMETADATA_TEAM_EVENTDATA = _descriptor.Descriptor(
  name='EventData',
  full_name='dota.CDOTAMatchMetadata.Team.EventData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CDOTAMatchMetadata.Team.EventData.event_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_points', full_name='dota.CDOTAMatchMetadata.Team.EventData.event_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='challenge_instance_id', full_name='dota.CDOTAMatchMetadata.Team.EventData.challenge_instance_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='challenge_quest_id', full_name='dota.CDOTAMatchMetadata.Team.EventData.challenge_quest_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='challenge_quest_challenge_id', full_name='dota.CDOTAMatchMetadata.Team.EventData.challenge_quest_challenge_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='challenge_completed', full_name='dota.CDOTAMatchMetadata.Team.EventData.challenge_completed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='challenge_rank_completed', full_name='dota.CDOTAMatchMetadata.Team.EventData.challenge_rank_completed', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='challenge_rank_previously_completed', full_name='dota.CDOTAMatchMetadata.Team.EventData.challenge_rank_previously_completed', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_owned', full_name='dota.CDOTAMatchMetadata.Team.EventData.event_owned', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_challenges_with_progress', full_name='dota.CDOTAMatchMetadata.Team.EventData.sub_challenges_with_progress', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wager_winnings', full_name='dota.CDOTAMatchMetadata.Team.EventData.wager_winnings', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cavern_challenge_active', full_name='dota.CDOTAMatchMetadata.Team.EventData.cavern_challenge_active', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cavern_challenge_winnings', full_name='dota.CDOTAMatchMetadata.Team.EventData.cavern_challenge_winnings', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_wagered', full_name='dota.CDOTAMatchMetadata.Team.EventData.amount_wagered', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_wager_amount', full_name='dota.CDOTAMatchMetadata.Team.EventData.team_wager_amount', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='periodic_point_adjustments', full_name='dota.CDOTAMatchMetadata.Team.EventData.periodic_point_adjustments', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cavern_challenge_map_results', full_name='dota.CDOTAMatchMetadata.Team.EventData.cavern_challenge_map_results', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cavern_challenge_plus_shard_winnings', full_name='dota.CDOTAMatchMetadata.Team.EventData.cavern_challenge_plus_shard_winnings', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actions_granted', full_name='dota.CDOTAMatchMetadata.Team.EventData.actions_granted', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1630,
  serialized_end=2373,
)

_CDOTAMATCHMETADATA_TEAM_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='dota.CDOTAMatchMetadata.Team.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CDOTAMatchMetadata.Team.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ability_upgrades', full_name='dota.CDOTAMatchMetadata.Team.Player.ability_upgrades', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_slot', full_name='dota.CDOTAMatchMetadata.Team.Player.player_slot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equipped_econ_items', full_name='dota.CDOTAMatchMetadata.Team.Player.equipped_econ_items', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kills', full_name='dota.CDOTAMatchMetadata.Team.Player.kills', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='dota.CDOTAMatchMetadata.Team.Player.items', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_kills_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.avg_kills_x16', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_deaths_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.avg_deaths_x16', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_assists_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.avg_assists_x16', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_gpm_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.avg_gpm_x16', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_xpm_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.avg_xpm_x16', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_kills_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.best_kills_x16', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_assists_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.best_assists_x16', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_gpm_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.best_gpm_x16', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_xpm_x16', full_name='dota.CDOTAMatchMetadata.Team.Player.best_xpm_x16', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='win_streak', full_name='dota.CDOTAMatchMetadata.Team.Player.win_streak', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_win_streak', full_name='dota.CDOTAMatchMetadata.Team.Player.best_win_streak', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fight_score', full_name='dota.CDOTAMatchMetadata.Team.Player.fight_score', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='farm_score', full_name='dota.CDOTAMatchMetadata.Team.Player.farm_score', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='support_score', full_name='dota.CDOTAMatchMetadata.Team.Player.support_score', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='push_score', full_name='dota.CDOTAMatchMetadata.Team.Player.push_score', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level_up_times', full_name='dota.CDOTAMatchMetadata.Team.Player.level_up_times', index=21,
      number=22, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_net_worth', full_name='dota.CDOTAMatchMetadata.Team.Player.graph_net_worth', index=22,
      number=23, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inventory_snapshot', full_name='dota.CDOTAMatchMetadata.Team.Player.inventory_snapshot', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_stats_calibrated', full_name='dota.CDOTAMatchMetadata.Team.Player.avg_stats_calibrated', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_style_criteria', full_name='dota.CDOTAMatchMetadata.Team.Player.auto_style_criteria', index=25,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_data', full_name='dota.CDOTAMatchMetadata.Team.Player.event_data', index=26,
      number=29, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strange_gem_progress', full_name='dota.CDOTAMatchMetadata.Team.Player.strange_gem_progress', index=27,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hero_xp', full_name='dota.CDOTAMatchMetadata.Team.Player.hero_xp', index=28,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='camps_stacked', full_name='dota.CDOTAMatchMetadata.Team.Player.camps_stacked', index=29,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='victory_prediction', full_name='dota.CDOTAMatchMetadata.Team.Player.victory_prediction', index=30,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lane_selection_flags', full_name='dota.CDOTAMatchMetadata.Team.Player.lane_selection_flags', index=31,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rampages', full_name='dota.CDOTAMatchMetadata.Team.Player.rampages', index=32,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triple_kills', full_name='dota.CDOTAMatchMetadata.Team.Player.triple_kills', index=33,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aegis_snatched', full_name='dota.CDOTAMatchMetadata.Team.Player.aegis_snatched', index=34,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rapiers_purchased', full_name='dota.CDOTAMatchMetadata.Team.Player.rapiers_purchased', index=35,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='couriers_killed', full_name='dota.CDOTAMatchMetadata.Team.Player.couriers_killed', index=36,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_worth_rank', full_name='dota.CDOTAMatchMetadata.Team.Player.net_worth_rank', index=37,
      number=40, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='support_gold_spent', full_name='dota.CDOTAMatchMetadata.Team.Player.support_gold_spent', index=38,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observer_wards_placed', full_name='dota.CDOTAMatchMetadata.Team.Player.observer_wards_placed', index=39,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sentry_wards_placed', full_name='dota.CDOTAMatchMetadata.Team.Player.sentry_wards_placed', index=40,
      number=43, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wards_dewarded', full_name='dota.CDOTAMatchMetadata.Team.Player.wards_dewarded', index=41,
      number=44, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stun_duration', full_name='dota.CDOTAMatchMetadata.Team.Player.stun_duration', index=42,
      number=45, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2376,
  serialized_end=3749,
)

_CDOTAMATCHMETADATA_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='dota.CDOTAMatchMetadata.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dota_team', full_name='dota.CDOTAMatchMetadata.Team.dota_team', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='players', full_name='dota.CDOTAMatchMetadata.Team.players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_experience', full_name='dota.CDOTAMatchMetadata.Team.graph_experience', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_gold_earned', full_name='dota.CDOTAMatchMetadata.Team.graph_gold_earned', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_net_worth', full_name='dota.CDOTAMatchMetadata.Team.graph_net_worth', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cm_first_pick', full_name='dota.CDOTAMatchMetadata.Team.cm_first_pick', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cm_captain_player_id', full_name='dota.CDOTAMatchMetadata.Team.cm_captain_player_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cm_bans', full_name='dota.CDOTAMatchMetadata.Team.cm_bans', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cm_picks', full_name='dota.CDOTAMatchMetadata.Team.cm_picks', index=8,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cm_penalty', full_name='dota.CDOTAMatchMetadata.Team.cm_penalty', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHMETADATA_TEAM_PLAYERKILL, _CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE, _CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT, _CDOTAMATCHMETADATA_TEAM_AUTOSTYLECRITERIA, _CDOTAMATCHMETADATA_TEAM_STRANGEGEMPROGRESS, _CDOTAMATCHMETADATA_TEAM_VICTORYPREDICTION, _CDOTAMATCHMETADATA_TEAM_SUBCHALLENGE, _CDOTAMATCHMETADATA_TEAM_CAVERNCHALLENGERESULT, _CDOTAMATCHMETADATA_TEAM_ACTIONGRANT, _CDOTAMATCHMETADATA_TEAM_EVENTDATA, _CDOTAMATCHMETADATA_TEAM_PLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=3749,
)

_CDOTAMATCHMETADATA = _descriptor.Descriptor(
  name='CDOTAMatchMetadata',
  full_name='dota.CDOTAMatchMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teams', full_name='dota.CDOTAMatchMetadata.teams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_rewards', full_name='dota.CDOTAMatchMetadata.item_rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CDOTAMatchMetadata.lobby_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='report_until_time', full_name='dota.CDOTAMatchMetadata.report_until_time', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_game_custom_table', full_name='dota.CDOTAMatchMetadata.event_game_custom_table', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary_event_id', full_name='dota.CDOTAMatchMetadata.primary_event_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_tips', full_name='dota.CDOTAMatchMetadata.match_tips', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHMETADATA_TEAM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=3749,
)


_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY_BYHEROTARGET = _descriptor.Descriptor(
  name='ByHeroTarget',
  full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.ByHeroTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.ByHeroTarget.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.ByHeroTarget.damage', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4718,
  serialized_end=4765,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY = _descriptor.Descriptor(
  name='DamageByAbility',
  full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_unit_index', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.source_unit_index', index=0,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ability_id', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.ability_id', index=1,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_hero_targets', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.by_hero_targets', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY_BYHEROTARGET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4539,
  serialized_end=4765,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT = _descriptor.Descriptor(
  name='CombatSegment',
  full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_time', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.game_time', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage_by_ability', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.damage_by_ability', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4400,
  serialized_end=4765,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD_BYHEROTARGET = _descriptor.Descriptor(
  name='ByHeroTarget',
  full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.ByHeroTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hero_id', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.ByHeroTarget.hero_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elapsed_duration', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.ByHeroTarget.elapsed_duration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_hidden', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.ByHeroTarget.is_hidden', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4929,
  serialized_end=5005,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD = _descriptor.Descriptor(
  name='BuffRecord',
  full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='buff_ability_id', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.buff_ability_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buff_modifier_name', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.buff_modifier_name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_hero_targets', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.by_hero_targets', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD_BYHEROTARGET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4768,
  serialized_end=5005,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='dota.CDOTAMatchPrivateMetadata.Team.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_slot', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.player_slot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_stream', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.position_stream', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='combat_segments', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.combat_segments', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage_unit_names', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.damage_unit_names', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buff_records', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.buff_records', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_kills', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.graph_kills', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_deaths', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.graph_deaths', index=7,
      number=8, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_assists', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.graph_assists', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_lasthits', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.graph_lasthits', index=9,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_denies', full_name='dota.CDOTAMatchPrivateMetadata.Team.Player.graph_denies', index=10,
      number=11, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT, _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4022,
  serialized_end=5005,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING = _descriptor.Descriptor(
  name='Building',
  full_name='dota.CDOTAMatchPrivateMetadata.Team.Building',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_name', full_name='dota.CDOTAMatchPrivateMetadata.Team.Building.unit_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_quant_x', full_name='dota.CDOTAMatchPrivateMetadata.Team.Building.position_quant_x', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_quant_y', full_name='dota.CDOTAMatchPrivateMetadata.Team.Building.position_quant_y', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='death_time', full_name='dota.CDOTAMatchPrivateMetadata.Team.Building.death_time', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5007,
  serialized_end=5108,
)

_CDOTAMATCHPRIVATEMETADATA_TEAM = _descriptor.Descriptor(
  name='Team',
  full_name='dota.CDOTAMatchPrivateMetadata.Team',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dota_team', full_name='dota.CDOTAMatchPrivateMetadata.Team.dota_team', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='players', full_name='dota.CDOTAMatchPrivateMetadata.Team.players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buildings', full_name='dota.CDOTAMatchPrivateMetadata.Team.buildings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER, _CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3866,
  serialized_end=5108,
)

_CDOTAMATCHPRIVATEMETADATA = _descriptor.Descriptor(
  name='CDOTAMatchPrivateMetadata',
  full_name='dota.CDOTAMatchPrivateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teams', full_name='dota.CDOTAMatchPrivateMetadata.teams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph_win_probability', full_name='dota.CDOTAMatchPrivateMetadata.graph_win_probability', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CDOTAMATCHPRIVATEMETADATA_TEAM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3752,
  serialized_end=5108,
)


_CMSGDOTADPCMATCH = _descriptor.Descriptor(
  name='CMsgDOTADPCMatch',
  full_name='dota.CMsgDOTADPCMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='dota.CMsgDOTADPCMatch.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dota.CMsgDOTADPCMatch.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5110,
  serialized_end=5208,
)

_CDOTAMATCHMETADATAFILE.fields_by_name['metadata'].message_type = _CDOTAMATCHMETADATA
_CDOTAMATCHMETADATA_TEAM_PLAYERKILL.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_AUTOSTYLECRITERIA.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_STRANGEGEMPROGRESS.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_VICTORYPREDICTION.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_SUBCHALLENGE.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_CAVERNCHALLENGERESULT.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_ACTIONGRANT.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_EVENTDATA.fields_by_name['sub_challenges_with_progress'].message_type = _CDOTAMATCHMETADATA_TEAM_SUBCHALLENGE
_CDOTAMATCHMETADATA_TEAM_EVENTDATA.fields_by_name['cavern_challenge_map_results'].message_type = _CDOTAMATCHMETADATA_TEAM_CAVERNCHALLENGERESULT
_CDOTAMATCHMETADATA_TEAM_EVENTDATA.fields_by_name['actions_granted'].message_type = _CDOTAMATCHMETADATA_TEAM_ACTIONGRANT
_CDOTAMATCHMETADATA_TEAM_EVENTDATA.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['equipped_econ_items'].message_type = base__gcmessages__pb2._CSOECONITEM
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['kills'].message_type = _CDOTAMATCHMETADATA_TEAM_PLAYERKILL
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['items'].message_type = _CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['inventory_snapshot'].message_type = _CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['auto_style_criteria'].message_type = _CDOTAMATCHMETADATA_TEAM_AUTOSTYLECRITERIA
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['event_data'].message_type = _CDOTAMATCHMETADATA_TEAM_EVENTDATA
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['strange_gem_progress'].message_type = _CDOTAMATCHMETADATA_TEAM_STRANGEGEMPROGRESS
_CDOTAMATCHMETADATA_TEAM_PLAYER.fields_by_name['victory_prediction'].message_type = _CDOTAMATCHMETADATA_TEAM_VICTORYPREDICTION
_CDOTAMATCHMETADATA_TEAM_PLAYER.containing_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA_TEAM.fields_by_name['players'].message_type = _CDOTAMATCHMETADATA_TEAM_PLAYER
_CDOTAMATCHMETADATA_TEAM.containing_type = _CDOTAMATCHMETADATA
_CDOTAMATCHMETADATA.fields_by_name['teams'].message_type = _CDOTAMATCHMETADATA_TEAM
_CDOTAMATCHMETADATA.fields_by_name['item_rewards'].message_type = dota__gcmessages__common__match__management__pb2._CLOBBYTIMEDREWARDDETAILS
_CDOTAMATCHMETADATA.fields_by_name['match_tips'].message_type = dota__gcmessages__common__pb2._CMSGMATCHTIPS
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY_BYHEROTARGET.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY.fields_by_name['by_hero_targets'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY_BYHEROTARGET
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT.fields_by_name['damage_by_ability'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD_BYHEROTARGET.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD.fields_by_name['by_hero_targets'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD_BYHEROTARGET
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER.fields_by_name['combat_segments'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER.fields_by_name['buff_records'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD
_CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM
_CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING.containing_type = _CDOTAMATCHPRIVATEMETADATA_TEAM
_CDOTAMATCHPRIVATEMETADATA_TEAM.fields_by_name['players'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER
_CDOTAMATCHPRIVATEMETADATA_TEAM.fields_by_name['buildings'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING
_CDOTAMATCHPRIVATEMETADATA_TEAM.containing_type = _CDOTAMATCHPRIVATEMETADATA
_CDOTAMATCHPRIVATEMETADATA.fields_by_name['teams'].message_type = _CDOTAMATCHPRIVATEMETADATA_TEAM
_CMSGDOTADPCMATCH.fields_by_name['match'].message_type = dota__gcmessages__common__pb2._CMSGDOTAMATCH
_CMSGDOTADPCMATCH.fields_by_name['metadata'].message_type = _CDOTAMATCHMETADATA
DESCRIPTOR.message_types_by_name['CDOTAMatchMetadataFile'] = _CDOTAMATCHMETADATAFILE
DESCRIPTOR.message_types_by_name['CDOTAMatchMetadata'] = _CDOTAMATCHMETADATA
DESCRIPTOR.message_types_by_name['CDOTAMatchPrivateMetadata'] = _CDOTAMATCHPRIVATEMETADATA
DESCRIPTOR.message_types_by_name['CMsgDOTADPCMatch'] = _CMSGDOTADPCMATCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CDOTAMatchMetadataFile = _reflection.GeneratedProtocolMessageType('CDOTAMatchMetadataFile', (_message.Message,), dict(
  DESCRIPTOR = _CDOTAMATCHMETADATAFILE,
  __module__ = 'dota_match_metadata_pb2'
  # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadataFile)
  ))
_sym_db.RegisterMessage(CDOTAMatchMetadataFile)

CDOTAMatchMetadata = _reflection.GeneratedProtocolMessageType('CDOTAMatchMetadata', (_message.Message,), dict(

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(

    PlayerKill = _reflection.GeneratedProtocolMessageType('PlayerKill', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_PLAYERKILL,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.PlayerKill)
      ))
    ,

    ItemPurchase = _reflection.GeneratedProtocolMessageType('ItemPurchase', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_ITEMPURCHASE,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.ItemPurchase)
      ))
    ,

    InventorySnapshot = _reflection.GeneratedProtocolMessageType('InventorySnapshot', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_INVENTORYSNAPSHOT,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.InventorySnapshot)
      ))
    ,

    AutoStyleCriteria = _reflection.GeneratedProtocolMessageType('AutoStyleCriteria', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_AUTOSTYLECRITERIA,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.AutoStyleCriteria)
      ))
    ,

    StrangeGemProgress = _reflection.GeneratedProtocolMessageType('StrangeGemProgress', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_STRANGEGEMPROGRESS,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.StrangeGemProgress)
      ))
    ,

    VictoryPrediction = _reflection.GeneratedProtocolMessageType('VictoryPrediction', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_VICTORYPREDICTION,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.VictoryPrediction)
      ))
    ,

    SubChallenge = _reflection.GeneratedProtocolMessageType('SubChallenge', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_SUBCHALLENGE,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.SubChallenge)
      ))
    ,

    CavernChallengeResult = _reflection.GeneratedProtocolMessageType('CavernChallengeResult', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_CAVERNCHALLENGERESULT,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.CavernChallengeResult)
      ))
    ,

    ActionGrant = _reflection.GeneratedProtocolMessageType('ActionGrant', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_ACTIONGRANT,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.ActionGrant)
      ))
    ,

    EventData = _reflection.GeneratedProtocolMessageType('EventData', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_EVENTDATA,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.EventData)
      ))
    ,

    Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM_PLAYER,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team.Player)
      ))
    ,
    DESCRIPTOR = _CDOTAMATCHMETADATA_TEAM,
    __module__ = 'dota_match_metadata_pb2'
    # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata.Team)
    ))
  ,
  DESCRIPTOR = _CDOTAMATCHMETADATA,
  __module__ = 'dota_match_metadata_pb2'
  # @@protoc_insertion_point(class_scope:dota.CDOTAMatchMetadata)
  ))
_sym_db.RegisterMessage(CDOTAMatchMetadata)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.PlayerKill)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.ItemPurchase)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.InventorySnapshot)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.AutoStyleCriteria)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.StrangeGemProgress)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.VictoryPrediction)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.SubChallenge)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.CavernChallengeResult)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.ActionGrant)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.EventData)
_sym_db.RegisterMessage(CDOTAMatchMetadata.Team.Player)

CDOTAMatchPrivateMetadata = _reflection.GeneratedProtocolMessageType('CDOTAMatchPrivateMetadata', (_message.Message,), dict(

  Team = _reflection.GeneratedProtocolMessageType('Team', (_message.Message,), dict(

    Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(

      CombatSegment = _reflection.GeneratedProtocolMessageType('CombatSegment', (_message.Message,), dict(

        DamageByAbility = _reflection.GeneratedProtocolMessageType('DamageByAbility', (_message.Message,), dict(

          ByHeroTarget = _reflection.GeneratedProtocolMessageType('ByHeroTarget', (_message.Message,), dict(
            DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY_BYHEROTARGET,
            __module__ = 'dota_match_metadata_pb2'
            # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.ByHeroTarget)
            ))
          ,
          DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT_DAMAGEBYABILITY,
          __module__ = 'dota_match_metadata_pb2'
          # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility)
          ))
        ,
        DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_COMBATSEGMENT,
        __module__ = 'dota_match_metadata_pb2'
        # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team.Player.CombatSegment)
        ))
      ,

      BuffRecord = _reflection.GeneratedProtocolMessageType('BuffRecord', (_message.Message,), dict(

        ByHeroTarget = _reflection.GeneratedProtocolMessageType('ByHeroTarget', (_message.Message,), dict(
          DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD_BYHEROTARGET,
          __module__ = 'dota_match_metadata_pb2'
          # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.ByHeroTarget)
          ))
        ,
        DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER_BUFFRECORD,
        __module__ = 'dota_match_metadata_pb2'
        # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team.Player.BuffRecord)
        ))
      ,
      DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_PLAYER,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team.Player)
      ))
    ,

    Building = _reflection.GeneratedProtocolMessageType('Building', (_message.Message,), dict(
      DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM_BUILDING,
      __module__ = 'dota_match_metadata_pb2'
      # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team.Building)
      ))
    ,
    DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA_TEAM,
    __module__ = 'dota_match_metadata_pb2'
    # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata.Team)
    ))
  ,
  DESCRIPTOR = _CDOTAMATCHPRIVATEMETADATA,
  __module__ = 'dota_match_metadata_pb2'
  # @@protoc_insertion_point(class_scope:dota.CDOTAMatchPrivateMetadata)
  ))
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Player)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Player.CombatSegment)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Player.CombatSegment.DamageByAbility.ByHeroTarget)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Player.BuffRecord)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Player.BuffRecord.ByHeroTarget)
_sym_db.RegisterMessage(CDOTAMatchPrivateMetadata.Team.Building)

CMsgDOTADPCMatch = _reflection.GeneratedProtocolMessageType('CMsgDOTADPCMatch', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTADPCMATCH,
  __module__ = 'dota_match_metadata_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgDOTADPCMatch)
  ))
_sym_db.RegisterMessage(CMsgDOTADPCMatch)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
